%define _hardened_build 1

Name:             zfs-fuse
Version:          0.7.2.2
Release:          %mkrel 5
Summary:          ZFS ported to Linux FUSE
Group:            System/Libraries
License:          CDDL
URL:              https://github.com/gordan-bobic/zfs-fuse
Source00:         http://github.com/gordan-bobic/zfs-fuse/archive/%{name}-%{version}.tar.gz
Source01:         zfs-fuse.service
Source02:         zfs-fuse.scrub
Source03:         zfs-fuse.sysconfig
Source04:         zfs-fuse-helper
Patch0:           zfs-fuse-0.7.2.2-stack.patch
Patch1:           zfs-fuse-0.7.2.2-python3.patch
Patch2:           tirpc.patch
Patch3:           common.patch
Patch4:           attr.patch
BuildRequires:    pkgconfig(fuse)
BuildRequires:    libaio-devel
BuildRequires:    scons
BuildRequires:    pkgconfig(zlib)
BuildRequires:    pkgconfig(openssl)
BuildRequires:    libattr-devel
BuildRequires:    pkgconfig(lzo2)
BuildRequires:    pkgconfig(bzip2)
BuildRequires:    pkgconfig(liblzma)
BuildRequires:    pkgconfig(libtirpc)
BuildRequires:    pkgconfig(systemd)
Requires:         fuse >= 2.7.4-1
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
# (2010 karsten@redhat.com) zfs-fuse doesn't have s390(x) implementations for atomic instructions
ExcludeArch:      s390 s390x aarch64

%description
ZFS is an advanced modern general-purpose filesystem from Sun
Microsystems, originally designed for Solaris/OpenSolaris.

This project is a port of ZFS to the FUSE framework for the Linux
operating system.

%prep
%setup -q

%patch0 -p0
%patch1 -p1
%patch2 -p1
%patch3 -p0
%patch4 -p1

f=LICENSE
mv $f $f.iso88591
iconv -o $f -f iso88591 -t utf8 $f.iso88591
rm -f $f.iso88591

chmod -x contrib/test-datasets
chmod -x contrib/find-binaries
chmod -x contrib/solaris/fixfiles.py
chmod -x contrib/zfsstress.py

%build
export CCFLAGS="%{optflags}"
pushd src

scons debug=2 optim='%{optflags}'

%install
pushd src
%scons_install debug=1 install_dir=%{_sbindir} man_dir=%{_mandir}/man8/ cfg_dir=%{_sysconfdir}/%{name}

install -Dp -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
install -Dp -m 0755 %{SOURCE2} %{buildroot}%{_sysconfdir}/cron.weekly/98-%{name}-scrub
install -Dp -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -Dp -m 0755 %{SOURCE4} %{buildroot}%{_sbindir}/zfs-fuse-helper

%post
# Move cache if upgrading
oldcache=/etc/zfs/zpool.cache      # this changed per 0.6.9, only needed when upgrading from earlier versions
newcache=/var/lib/zfs/zpool.cache

if [[ -f $oldcache && ! -e $newcache ]]; then
  echo "Moving existing zpool.cache to new location"
  mkdir -p $(dirname $newcache)
  mv $oldcache $newcache
else
  if [ -e $oldcache ]; then
    echo "Note: old zpool.cache present but no longer used ($oldcache)"
  fi
fi

%_post_service zfs-fuse

%preun
%_preun_service zfs-fuse

%postun
%systemd_postun_with_restart zfs-fuse.service
echo "Removing files since we removed the last package"
rm -rf /var/run/zfs
rm -rf /var/lock/zfs

%files
%license LICENSE
%doc BUGS CHANGES contrib HACKING README
%doc README.NFS STATUS TESTING TODO
%{_sbindir}/zdb
%{_sbindir}/zfs
%{_sbindir}/zfs-fuse
%{_sbindir}/zfs-fuse-helper
%{_sbindir}/zpool
%{_sbindir}/zstreamdump
%{_sbindir}/ztest
%{_sbindir}/mount.zfs
%{_unitdir}/%{name}.service
%{_sysconfdir}/cron.weekly/98-%{name}-scrub
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_sysconfdir}/%{name}/
%{_mandir}/man8/zfs-fuse.8.*
%{_mandir}/man8/zdb.8.*
%{_mandir}/man8/zfs.8.*
%{_mandir}/man8/zpool.8.*
%{_mandir}/man8/zstreamdump.8.*


%changelog
* Wed Sep 02 2020 tv <tv> 0.7.2.2-5.mga8
+ Revision: 1620737
- patch 4: fix xattr.h inclusion, thus fixing last build issue
- actually apply patch 3
- fix-build by removing old aarch64 fixup
- re-enable arm
- fix build with gcc-10

* Sun Apr 26 2020 wally <wally> 0.7.2.2-3.mga8
+ Revision: 1572325
- build without prelink

* Sat Feb 15 2020 umeabot <umeabot> 0.7.2.2-2.mga8
+ Revision: 1525215
- Mageia 8 Mass Rebuild

* Fri Apr 05 2019 daviddavid <daviddavid> 0.7.2.2-1.mga7
+ Revision: 1386238
- new version: 0.7.2.2
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild

* Mon Oct 02 2017 daviddavid <daviddavid> 0.7.0-4.mga7
+ Revision: 1162717
- patch4: fix build with scons 3.0

* Thu Aug 31 2017 guillomovitch <guillomovitch> 0.7.0-3.mga7
+ Revision: 1150312
- rebuild for latest openssl

* Mon May 16 2016 tv <tv> 0.7.0-2.mga6
+ Revision: 1016111
- BR systemd in order to fix %%post

* Mon May 02 2016 tv <tv> 0.7.0-1.mga6
+ Revision: 1008798
- imported package zfs-fuse

